rayoptics.raytr package
=======================

.. automodule:: rayoptics.raytr
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   rayoptics.raytr.analyses
   rayoptics.raytr.opticalspec
   rayoptics.raytr.raytrace
   rayoptics.raytr.sampler
   rayoptics.raytr.trace
   rayoptics.raytr.traceerror
   rayoptics.raytr.vigcalc
   rayoptics.raytr.waveabr
